Documentation
¶
Index ¶
- Variables
- type Queue
- func (*Queue) Descriptor() ([]byte, []int)deprecated
- func (x *Queue) GetMaxRetryCount() uint32
- func (x *Queue) GetName() string
- func (x *Queue) GetTaskTimeout() *durationpb.Duration
- func (*Queue) ProtoMessage()
- func (x *Queue) ProtoReflect() protoreflect.Message
- func (x *Queue) Reset()
- func (x *Queue) String() string
- type Task
- func (*Task) Descriptor() ([]byte, []int)deprecated
- func (x *Task) GetAttemptCount() uint32
- func (x *Task) GetDeadline() *timestamppb.Timestamp
- func (x *Task) GetDescription() string
- func (x *Task) GetId() string
- func (x *Task) GetParams() *structpb.ListValue
- func (*Task) ProtoMessage()
- func (x *Task) ProtoReflect() protoreflect.Message
- func (x *Task) Reset()
- func (x *Task) String() string
Constants ¶
This section is empty.
Variables ¶
var File_daangn_eboolkiq_queue_proto protoreflect.FileDescriptor
var File_daangn_eboolkiq_task_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Queue ¶
type Queue struct {
// name is the name of queue.
// name must be unique and must consist of alphanumeric and dot(.).
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// task_timeout is the duration to wait for the task to complete its
// operation. The max value of task_timeout is 10 minute.
//
// If the task_timeout is over 1s and the task_timeout has elapsed since
// the task was taken, the task is considered failed and retried according
// to the value of the max_retry_count.
TaskTimeout *durationpb.Duration `protobuf:"bytes,2,opt,name=task_timeout,json=taskTimeout,proto3" json:"task_timeout,omitempty"`
// max_retry_count is the count to retry task on failed its operation.
//
// If the task fails over max_retry_count, the task will be disappear.
MaxRetryCount uint32 `protobuf:"varint,3,opt,name=max_retry_count,json=maxRetryCount,proto3" json:"max_retry_count,omitempty"`
// contains filtered or unexported fields
}
func (*Queue) Descriptor
deprecated
func (*Queue) GetMaxRetryCount ¶
func (*Queue) GetTaskTimeout ¶
func (x *Queue) GetTaskTimeout() *durationpb.Duration
func (*Queue) ProtoMessage ¶
func (*Queue) ProtoMessage()
func (*Queue) ProtoReflect ¶
func (x *Queue) ProtoReflect() protoreflect.Message
type Task ¶
type Task struct {
// id is unique value that identifies the task
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// params is the parameter for processing the task.
Params *structpb.ListValue `protobuf:"bytes,2,opt,name=params,proto3" json:"params,omitempty"`
// description is the description of the task.
Description string `protobuf:"bytes,3,opt,name=description,proto3" json:"description,omitempty"`
// deadline is the deadline of the task.
//
// If task is fetched, the task should be finished before deadline.
// After the deadline is exceeded, the task is treated as failed.
Deadline *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=deadline,proto3" json:"deadline,omitempty"`
// attempt_count is the number of times the task was attempted.
AttemptCount uint32 `protobuf:"varint,5,opt,name=attempt_count,json=attemptCount,proto3" json:"attempt_count,omitempty"`
// contains filtered or unexported fields
}
func (*Task) Descriptor
deprecated
func (*Task) GetAttemptCount ¶
func (*Task) GetDeadline ¶
func (x *Task) GetDeadline() *timestamppb.Timestamp
func (*Task) GetDescription ¶
func (*Task) ProtoMessage ¶
func (*Task) ProtoMessage()
func (*Task) ProtoReflect ¶
func (x *Task) ProtoReflect() protoreflect.Message
Click to show internal directories.
Click to hide internal directories.